@@ -14,7 +14,7 @@ use Carp qw/croak/;
 use DBIx::Simplish::Result;
 use Regexp::Common;
 
-our $VERSION = '1.000_001'; # TRIAL VERSION
+our $VERSION = '1.001'; # VERSION
 
 my $connection_mode = Type::Tiny::Enum->new(values => [qw/ping fixup no_ping/]);
 
@@ -225,6 +225,11 @@ sub iquery {
     sql_interp(@args);
 }
 
+sub call {
+    my ($self, $procedure, @args) = @_;
+    return $self->query("CALL $procedure(??)", @args);
+}
+
 sub func {
     my ($self, @args) = @_;
     return $self->_run(sub {$_->func(@args)});
@@ -279,7 +284,7 @@ DBIx::Simplish - L<DBIx::Simple> + L<DBIx::Connector> + extras.
 
 =head1 VERSION
 
-version 1.000_001
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -308,6 +313,9 @@ version 1.000_001
     $result = $db->update($table, \%fieldvals, \%where)
     $result = $db->delete($table, \%where)
 
+    # Only for MySQL
+    $result = $db->call($procedure, @args)
+
 =head2 DBIx::Simplish::Result
 
     @columns = $result->columns
@@ -460,6 +468,12 @@ binds to the C<query> method.
 
 See also: L<SQL::Interp>.
 
+=head2 call
+
+Shortcut for calling a MySQL procedure.
+C<< $db->call($procedure_name, @args) >> is equivalent to
+C<< $db->query("CALL $procedure_name(??)", @args) >>.
+
 =head2 func
 
 Proxy for L<C<func> method of DBI|DBI/func>
